@@ -40,7 +40,7 @@ __END__
 
 =head1 NAME
 
-PNI::Node::Perlop::StringwiseEqual - PNI node that implements Perl == operator
+PNI::Node::Perlop::StringwiseEqual - PNI node that implements Perl eq operator
 
 =head1 AUTHOR
 
